-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

newTalent{
	name = "lich",
	type = {"undead/lich", 1},
	mode = "passive",
	require = undeads_req1,
	points = 5,
	on_learn = function(self, t)
		self.inc_stats[self.STAT_MAG] = self.inc_stats[self.STAT_MAG] + 2
		self:onStatChange(self.STAT_MAG, 2)
		self.inc_stats[self.STAT_WIL] = self.inc_stats[self.STAT_WIL] + 2
		self:onStatChange(self.STAT_WIL, 2)
	end,
	on_unlearn = function(self, t)
		self.inc_stats[self.STAT_MAG] = self.inc_stats[self.STAT_MAG] - 2
		self:onStatChange(self.STAT_MAG, -2)
		self.inc_stats[self.STAT_WIL] = self.inc_stats[self.STAT_WIL] - 2
		self:onStatChange(self.STAT_WIL, -2)
	end,
	info = function(self, t)
		return ([[Improves your skeletal condition, increasing magic and willpower by %d.]]):format(2 * self:getTalentLevelRaw(t))
	end,
}

newTalent{
	name = "magical power",
	type = {"undead/lich", 2},
	require = undeads_req2,
	points = 5,
	cooldown = 15,
	tactical = { ATTACK = 2 },
	range = 1,
	requires_target = true,
	on_learn = function(self, t)
		self.max_mana = self.max_mana + 30
		self.max_vim = self.max_vim + 10
	end,
	on_unlearn = function(self, t)
		self.max_mana = self.max_mana - 30
		self.max_vim = self.max_vim - 10
	end,
	info = function(self, t)
		return ([[Increases you max mana by %d and your max vim by %d]]):
		format(30 * self:getTalentLevelRaw(t),10 * self:getTalentLevelRaw(t))
	end,
}

newTalent{
	name = "liches aura",
	type = {"undead/lich", 3},
	require = undeads_req3,
	points = 5,
	vim = 12,
	mana = 10,
	cooldown = 50,
	tactical = { ATTACKAREA = 2},
	direct_hit = true,
	requires_target = true,
	range = 0,
	radius = function(self, t) return 1 + self:getTalentLevelRaw(t)/2 end,
	getDuration = function(self, t) return 5 + self:combatSpellpower(0.05) + self:getTalentLevel(t) end,
	getDamage = function(self, t) return self:combatTalentSpellDamage(t, 28, 80)  end,
	action = function(self, t)
		game.level.map:addEffect(self,	self.x, self.y, t.getDuration(self, t),
			DamageType.DRAIN_MAGE, t.getDamage(self, t),
			t.radius(self,t),
			5, nil,
			engine.Entity.new{alpha=100, display='', color_br=200, color_bg=100, color_bb=200},
			function(e)
				e.x = e.src.x
				e.y = e.src.y
				return true
			end,
			false
			
		)
		game:playSoundNear(self, "talents/fire")
		return true
	end,
	info = function(self, t)
		local damage = t.getDamage(self, t)
		local radius = t.radius(self,t)
		local duration = t.getDuration(self, t)
		return ([[An aura of magic emenates from you draining those nearby of their life source. You will deal %0.2f arcane damage over %d turns in a radius of %d.  You will replinish 1/5 of the damage as vim and 7/10 of the damage as mana 
		The damage will increase with the Magic stat]]):format(damDesc(self, DamageType.ARCANE, damage),duration,radius)
	end,
}

newTalent{
	name = "raise the dead",
	type = {"undead/lich", 4},
	require = racial_req4,
	mode = "sustained",
	points = 5,
	no_energy = true,
	sustain_vim = 60,
	sustain_mana = 100,
	cooldown = function(self, t) return 50 - self:getTalentLevel(t) * 3 end,
	no_npc_use = true,
	activate = function(self, t)
	game:playSoundNear(self, "talents/spell_generic2")
		local ret = {
			particle = self:addParticles(Particles.new("darkness_shield", 1))
		}
		return ret
	end,
	deactivate = function(self, t, p)
		self:removeParticles(p.particle)
		return true
	end,
	info = function(self, t)
		return ([[Reach through the collective psionic gestalt of the yeeks, the Way, to call for immediate help.
		Summons up to 3 yeek mindslayers to your side.]])
	end,
}
